from distutils.core import setup

setup(
    name='insPyred_print',
    version='v1.0',
    packages=['inspyred_print'],
    url='https://github.com/Inspyre-Softworks/inspyred_print',
    license='WTFYW',
    author='Taylor-Jayde J. Blackstone',
    author_email='t.blackstone@inspyre.tech',
    description='A very simple module containing some color codes for line printing in Python'
)
